@@ -1,5 +1,5 @@
-use std::borrow::Cow;
 use crate::prelude::TractResult;
+use std::borrow::Cow;
 
 pub trait ResolveTo<Concrete> {
     type Param: ?Sized;
@@ -34,6 +34,14 @@ impl<S: ResolveTo<C>, C: Clone> GeometryBound<S, C> {
         }
     }
 
+    pub fn as_concrete(&self) -> Option<&C> {
+        if let Self::Concrete(conc) = self {
+            Some(conc)
+        } else {
+            None
+        }
+    }
+
     pub fn optimize_if(self, param: Option<&S::Param>) -> TractResult<Self> {
         if let Some(param) = param {
             self.into_concrete(&param)
