@@ -12,7 +12,7 @@
 //! // build a simple model that just add 3 to each input component
 //! let mut model = TypedModel::default();
 //!
-//! let input_fact = TypedFact::dt_shape(f32::datum_type(), &[3]);
+//! let input_fact = f32::fact(&[3]);
 //! let input = model.add_source("input", input_fact).unwrap();
 //! let three = model.add_const("three".to_string(), tensor1(&[3f32])).unwrap();
 //! let add = model.wire_node("add".to_string(),
@@ -65,6 +65,8 @@ extern crate proptest;
 pub extern crate tract_data;
 pub extern crate tract_linalg;
 
+#[macro_use]
+pub mod macros;
 #[macro_use]
 pub mod ops;
 
@@ -116,6 +118,7 @@ pub mod internal {
         dispatch_copy, dispatch_datum, dispatch_datum_by_size, dispatch_floatlike, dispatch_numbers,
     };
     pub use tvec;
+    pub use dims;
     pub use {args_1, args_2, args_3, args_4, args_5, args_6, args_7, args_8};
     pub use {as_op, impl_op_same_as, not_a_typed_op, op_as_typed_op};
     pub use {bin_to_super_type, element_wise, element_wise_oop};
