@@ -7,6 +7,7 @@ mod gather_elements;
 mod gather_nd;
 mod one_hot;
 mod pad;
+mod range;
 mod reshape;
 mod scatter_elements;
 mod scatter_nd;
@@ -22,6 +23,7 @@ pub use self::gather_nd::GatherNd;
 pub use self::one_hot::OneHot;
 pub use self::pad::{Pad, PadMode};
 pub use self::reshape::FiniteReshape;
+pub use self::range::Range;
 pub use self::scatter_elements::ScatterElements;
 pub use self::scatter_nd::ScatterNd;
 pub use self::slice::Slice;
