@@ -510,7 +510,7 @@ impl TypedOp for AxisOp {
     fn output_facts(&self, inputs: &[&TypedFact]) -> TractResult<TVec<TypedFact>> {
         let mut shape = inputs[0].shape.clone();
         self.change_shape(&mut shape, false)?;
-        Ok(tvec!(TypedFact::dt_shape(inputs[0].datum_type, shape)))
+        Ok(tvec!(inputs[0].datum_type.fact(shape)))
     }
 
     fn invariants(
@@ -519,7 +519,8 @@ impl TypedOp for AxisOp {
         outputs: &[&TypedFact],
     ) -> TractResult<Invariants> {
         let mut axes = vec![];
-        for i in 0..outputs[0].rank() {
+        let is_rm = matches!(self, AxisOp::Rm(_));
+        for i in 0..(outputs[0].rank() + is_rm as usize) {
             if let Some(out) = self.transform_axis(i) {
                 axes.push(AxisInfo {
                     inputs: tvec!(Some(i)),
@@ -1075,8 +1076,7 @@ mod proptests {
     impl ComposeProblem {
         pub fn model(&self) -> TractResult<TypedModel> {
             let mut model = TypedModel::default();
-            let mut wire =
-                model.add_source("source", TypedFact::dt_shape(i64::datum_type(), &self.input))?;
+            let mut wire = model.add_source("source", i64::fact(&self.input))?;
             for (ix, op) in self.ops.iter().enumerate() {
                 wire = model.wire_node(format!("op_{}", ix), op.clone(), &[wire])?[0];
             }
