@@ -76,9 +76,7 @@ mod tests {
         let _ = env_logger::Builder::from_env("TRACT_LOG").try_init();
         let mut model = {
             let mut model = TypedModel::default();
-            let input = model
-                .add_source("input", TypedFact::dt_shape(i32::datum_type(), [len].as_ref()))
-                .unwrap();
+            let input = model.add_source("input", i32::fact(&[len])).unwrap();
             let crop = model
                 .wire_node(
                     "crop",
