@@ -6,17 +6,16 @@ use num_traits::int::PrimInt;
 use num_traits::{Float, Zero};
 use tract_data::internal::ClampCast;
 pub use tract_data::prelude::round_ties_to_even;
-use tract_linalg::mmm::RoundingPolicy;
-use tract_linalg::ScaleShiftAndRound;
+use tract_linalg::{ScaleShiftAndRound, Scaler};
 use tract_num_traits::AsPrimitive;
 
 bin_to_super_type!(add, Add,
-    declutter_unary: declutter_unary_add,
-    flip:commute,
-    linalg: Add,
-    validation: Validation::Rounding,
-    q: [i8, u8, i32, i32] => add_quant;
-    [f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64, TDim] => |c, a, b| *c = a.clone() + b);
+                   declutter_unary: declutter_unary_add,
+                   flip:commute,
+                   linalg: Add,
+                   validation: Validation::Rounding,
+                   q: [i8, u8, i32, i32] => add_quant;
+                   [f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64, TDim] => |c, a, b| *c = a.clone() + b);
 
 fn add_quant<T>(c: &mut T, a: &T, b: &T, zp: i32, _: f32)
 where
@@ -40,7 +39,7 @@ fn declutter_unary_add(
     }
 }
 
-bin_to_super_type!(sub, Sub, 
+bin_to_super_type!(sub, Sub,
     declutter_unary: declutter_unary_sub, flip:flip_sub, linalg:Sub,
     q: [i8, u8, i32, i32] => sub_quant;
     [f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64, TDim] => |c, a, b| *c = a.clone() - b);
@@ -72,82 +71,82 @@ fn declutter_unary_sub(
 }
 
 bin_to_super_type!(mul, Mul,
- cost: |dt| tvec!((Cost::FMA(dt), 1)),
- declutter_unary: declutter_unary_mul,
- flip: commute,
- linalg: Mul,
- out_of_place: |c:&mut Tensor, a:&Tensor, b: &Tensor| -> TractResult<bool> {
-     if c.datum_type() == TDim::datum_type() &&
-         a.datum_type() == TDim::datum_type() && b.datum_type() == TDim::datum_type() {
-             let a = a.to_array_view::<TDim>()?;
-             let b = b.cast_to::<i32>()?;
-             let b = b.to_array_view::<i32>()?;
-             let c = c.to_array_view_mut::<TDim>()?;
-             crate::ndarray::Zip::from(c).and_broadcast(a).and_broadcast(b).for_each(|c,a,b| *c = a.clone() * *b);
-             Ok(true)
-         }
-         else {
-             match c.datum_type() {
-                 DatumType::QI8(params) => {
-                    let (zp, scale) = params.zp_scale();
-                    let a = a.to_array_view::<i8>()?;
-                    let b = b.to_array_view::<i8>()?;
-                    let c = c.to_array_view_mut::<i8>()?;
-                    crate::ndarray::Zip::from(c)
+cost: |dt| tvec!((Cost::FMA(dt), 1)),
+declutter_unary: declutter_unary_mul,
+flip: commute,
+linalg: Mul,
+out_of_place: |c:&mut Tensor, a:&Tensor, b: &Tensor| -> TractResult<bool> {
+    if c.datum_type() == TDim::datum_type() &&
+        a.datum_type() == TDim::datum_type() && b.datum_type() == TDim::datum_type() {
+            let a = a.to_array_view::<TDim>()?;
+            let b = b.cast_to::<i32>()?;
+            let b = b.to_array_view::<i32>()?;
+            let c = c.to_array_view_mut::<TDim>()?;
+            crate::ndarray::Zip::from(c).and_broadcast(a).and_broadcast(b).for_each(|c,a,b| *c = a.clone() * *b);
+            Ok(true)
+        }
+    else {
+        match c.datum_type() {
+            DatumType::QI8(params) => {
+                let (zp, scale) = params.zp_scale();
+                let a = a.to_array_view::<i8>()?;
+                let b = b.to_array_view::<i8>()?;
+                let c = c.to_array_view_mut::<i8>()?;
+                crate::ndarray::Zip::from(c)
                     .and_broadcast(a)
                     .and_broadcast(b)
                     .for_each(|c,a,b| *c = scale_by((*a as i16 - zp as i16) * (*b as i16 - zp as i16) + zp as i16, scale).clamp_cast());
-                    Ok(true)
-                 }
-                 DatumType::QU8(params) => {
-                    let (zp, scale) = params.zp_scale();
-                    let a = a.to_array_view::<u8>()?;
-                    let b = b.to_array_view::<u8>()?;
-                    let c = c.to_array_view_mut::<u8>()?;
-                    crate::ndarray::Zip::from(c)
+                Ok(true)
+            }
+            DatumType::QU8(params) => {
+                let (zp, scale) = params.zp_scale();
+                let a = a.to_array_view::<u8>()?;
+                let b = b.to_array_view::<u8>()?;
+                let c = c.to_array_view_mut::<u8>()?;
+                crate::ndarray::Zip::from(c)
                     .and_broadcast(a)
                     .and_broadcast(b)
                     .for_each(|c,a,b| *c = scale_by((*a as i16 - zp as i16) * (*b as i16 - zp as i16) + zp as i16, scale).clamp_cast());
-                    Ok(true)
-                 }
-                 _ => Ok(false)
-             }
-         }
- },
- [f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64, TDim] => |c, a, b| *c = a.clone() * b
+                Ok(true)
+            }
+            _ => Ok(false)
+        }
+    }
+},
+[f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64, TDim] => |c, a, b| *c = a.clone() * b
 );
 
 bin_to_super_type!(div, Div,
- cost: |dt| tvec!((Cost::Div(dt), 1)),
- declutter_bin: declutter_bin_div,
- flip: flip_div,
- out_of_place: |c:&mut Tensor, a:&Tensor, b: &Tensor| -> TractResult<bool> {
-     if c.datum_type() == TDim::datum_type() &&
-         a.datum_type() == TDim::datum_type() && b.datum_type() == TDim::datum_type() {
-             let a = a.to_array_view::<TDim>()?;
-             let b = b.cast_to::<i32>()?;
-             let b = b.to_array_view::<i32>()?;
-             let c = c.to_array_view_mut::<TDim>()?;
-             crate::ndarray::Zip::from(c).and_broadcast(a).and_broadcast(b).for_each(|c,a,b| *c = a.clone() / *b);
-             Ok(true)
+cost: |dt| tvec!((Cost::Div(dt), 1)),
+declutter_bin: declutter_bin_div,
+flip: flip_div,
+out_of_place: |c:&mut Tensor, a:&Tensor, b: &Tensor| -> TractResult<bool> {
+    if c.datum_type() == TDim::datum_type() &&
+        a.datum_type() == TDim::datum_type() && b.datum_type() == TDim::datum_type() {
+            let a = a.to_array_view::<TDim>()?;
+            let b = b.cast_to::<i32>()?;
+            let b = b.to_array_view::<i32>()?;
+            let c = c.to_array_view_mut::<TDim>()?;
+            crate::ndarray::Zip::from(c).and_broadcast(a).and_broadcast(b).for_each(|c,a,b| *c = a.clone() / *b);
+            Ok(true)
         } else if c.datum_type().is_quantized() || b.datum_type().is_quantized() || a.datum_type().is_quantized() {
-             let a_f32 = a.cast_to::<f32>()?;
-             let a_f32 = a_f32.to_array_view::<f32>()?;
-             let b_f32 = b.cast_to::<f32>()?;
-             let b_f32 = b_f32.to_array_view::<f32>()?;
-             let c_f32 = &a_f32 / &b_f32;
-             *c = c_f32.into_tensor().cast_to_dt(c.datum_type())?.into_owned();
-             Ok(true)
-         } else {
-             Ok(false)
-         }
- },
- [f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64] => |c, a, b| *c = a.clone() / b
+            let a_f32 = a.cast_to::<f32>()?;
+            let a_f32 = a_f32.to_array_view::<f32>()?;
+            let b_f32 = b.cast_to::<f32>()?;
+            let b_f32 = b_f32.to_array_view::<f32>()?;
+            let c_f32 = &a_f32 / &b_f32;
+            *c = c_f32.into_tensor().cast_to_dt(c.datum_type())?.into_owned();
+            Ok(true)
+        } else {
+            Ok(false)
+        }
+},
+[f32, i8, i16, i32, i64, u8, u16, u32, u64, f16, f64] => |c, a, b| *c = a.clone() / b
 );
 
 bin_to_super_type!(rem, Rem,
                    eval_override: |a:Arc<Tensor>, b: Arc<Tensor>| -> TractResult<Tensor> {
-                       if 
+                       if
                            a.datum_type() == TDim::datum_type() && b.datum_type() == TDim::datum_type() {
                                let a = a.to_array_view::<TDim>()?;
                                let b = b.cast_to::<i32>()?;
@@ -185,8 +184,7 @@ bin_to_super_type!(min, Min, flip:commute, linalg:Min,
 bin_to_super_type!(max, Max, flip:commute, linalg:Max,
                    q: [i8, u8, i32] => |c, a, b, _, _| *c = if a < b { *b } else { *a };
                    [f32, f64] => |c,a,b| *c = a.max(*b),
-                   [i8, i16, i32, i64, u8, u16, u32, u64] => |c, a, b| *c = *a.max(b))
-                ;
+                   [i8, i16, i32, i64, u8, u16, u32, u64] => |c, a, b| *c = *a.max(b));
 
 bin_to_super_type!(pow, Pow,
                    flip: flip_pow,
@@ -269,7 +267,8 @@ fn declutter_unary_mul_magic_values(
         let shape = crate::broadcast::multi_broadcast(&[
             fact.shape.to_vec(),
             a.shape().iter().map(|d| d.to_dim()).collect(),
-        ]).with_context(|| format!("Can not broadcast {:?} and {:?}", fact.shape, a))?;
+        ])
+        .with_context(|| format!("Can not broadcast {:?} and {:?}", fact.shape, a))?;
         let broadcast = crate::ops::array::MultiBroadcastTo::new(shape.into());
         let broadcast = patch.wire_node(&node.name, broadcast, &[zero])?;
         patch.shunt_outside(model, node.id.into(), broadcast[0])?;
@@ -362,9 +361,19 @@ fn declutter_unary_flipped_pow(
                 square(),
             )?));
         } else if a == 3.0 {
-            return Ok(Some(TypedModelPatch::replace_single_op(model, node, &node.inputs, cube())?));
+            return Ok(Some(TypedModelPatch::replace_single_op(
+                model,
+                node,
+                &node.inputs,
+                cube(),
+            )?));
         } else if a == 0.5 {
-            return Ok(Some(TypedModelPatch::replace_single_op(model, node, &node.inputs, sqrt())?));
+            return Ok(Some(TypedModelPatch::replace_single_op(
+                model,
+                node,
+                &node.inputs,
+                sqrt(),
+            )?));
         }
     }
     Ok(None)
@@ -475,8 +484,8 @@ element_wise!(round, Round, [f16, f32, f64] => |_, xs| {
 };
 q: [i8, u8, i32] => f32::round);
 
-element_wise!(q_scale, QScale {mult: i32, policy: RoundingPolicy, shift: usize},[i32] => |op, xs| {
-    xs.iter_mut().for_each(|x| *x = x.q_scale(op.mult, op.shift, op.policy));
+element_wise!(q_scale, QScale{scaler: Scaler},[i32] => |op, xs| {
+    xs.iter_mut().for_each(|x| *x = x.q_scale(op.scaler));
     Ok(())
 });
 
@@ -541,19 +550,19 @@ element_wise!(tanh, Tanh,
  cost: |dt| {tvec!((Cost::FMA(dt), 11), (Cost::Div(dt), 1))}
 );
 
-element_wise!(acosh, Acosh, [f16, f32, f64] => |_, xs| { 
-    xs.iter_mut().for_each(|x| *x = x.acosh()); 
-    Ok(()) 
+element_wise!(acosh, Acosh, [f16, f32, f64] => |_, xs| {
+    xs.iter_mut().for_each(|x| *x = x.acosh());
+    Ok(())
 };
 q: [i8, u8, i32] => f32::acosh);
-element_wise!(asinh, Asinh, [f16, f32, f64] => |_, xs| { 
-    xs.iter_mut().for_each(|x| *x = x.asinh()); 
-    Ok(()) 
+element_wise!(asinh, Asinh, [f16, f32, f64] => |_, xs| {
+    xs.iter_mut().for_each(|x| *x = x.asinh());
+    Ok(())
 };
 q: [i8, u8, i32] => f32::asinh);
-element_wise!(atanh, Atanh, [f16, f32, f64] => |_, xs| { 
-    xs.iter_mut().for_each(|x| *x = x.atanh()); 
-    Ok(()) 
+element_wise!(atanh, Atanh, [f16, f32, f64] => |_, xs| {
+    xs.iter_mut().for_each(|x| *x = x.atanh());
+    Ok(())
 };
 q: [i8, u8, i32] => f32::atanh);
 
@@ -591,7 +600,7 @@ mod tests {
     #[test]
     fn mul_as_shift() -> TractResult<()> {
         let mut model = TypedModel::default();
-        let x = model.add_source("a", TypedFact::dt_shape(i32::datum_type(), &[2usize, 2]))?;
+        let x = model.add_source("a", i32::fact(&[2usize, 2]))?;
         let y = model.wire_node("c", mul::unary(rctensor2(&[[4]])), [x].as_ref())?[0];
         model.set_output_outlets(&[y])?;
         let result = SimplePlan::new(&model)?.run(tvec!(tensor2(&[[1, 2], [3, 4]])))?;
@@ -607,7 +616,7 @@ mod tests {
     #[test]
     fn div_as_shift() -> TractResult<()> {
         let mut model = TypedModel::default();
-        let x = model.add_source("a", TypedFact::dt_shape(i32::datum_type(), &[2usize, 2]))?;
+        let x = model.add_source("a", i32::fact(&[2usize, 2]))?;
         let s = model.add_const("shift", tensor2(&[[4]]))?;
         let y = model.wire_node("c", div::bin_typed(), [x, s].as_ref())?[0];
         model.set_output_outlets(&[y])?;
