@@ -2,9 +2,9 @@ use crate::internal::*;
 use ndarray::*;
 
 use tract_linalg::mmm::{
-    BinOp, FusedSpec, InputStoreSpec, MatMatMul, OutputStore, OutputStoreSpec, RoundingPolicy,
-    ScratchSpace,
+    BinOp, FusedSpec, InputStoreSpec, MatMatMul, OutputStore, OutputStoreSpec, ScratchSpace,
 };
+use tract_linalg::Scaler;
 
 #[derive(PartialEq, Clone, Hash, Debug)]
 pub enum ProtoFusedSpec {
@@ -13,7 +13,7 @@ pub enum ProtoFusedSpec {
     BinPerCol(AttrOrInput, BinOp),
     AddRowColProducts(AttrOrInput, AttrOrInput),
     AddUnicast(AttrOrInput),
-    QScale(usize, RoundingPolicy, i32),
+    Scaler(Scaler),
     Store,
 }
 
@@ -39,7 +39,7 @@ impl ProtoFusedSpec {
                 }
                 FusedSpec::AddUnicast(output_spec.wrap(&view))
             },
-            ProtoFusedSpec::QScale(s, rp, m) => FusedSpec::QScale(*s, *rp, *m),
+            ProtoFusedSpec::Scaler(scaler) => scaler.as_fused_spec(),
             ProtoFusedSpec::Store => FusedSpec::Store(output),
         }
     }
@@ -244,7 +244,9 @@ fn eval(
                         .b_storage
                         .wrap(&TensorView::at_prefix_unchecked(&inputs[0], &*b_prefix))?,
                 });
-                f.extend(fused.iter().map(|f| f.resolve(inputs, prefix.slice(), &c_storage, c_store)));
+                f.extend(
+                    fused.iter().map(|f| f.resolve(inputs, prefix.slice(), &c_storage, c_store)),
+                );
                 op.mmm.run_with_scratch_space(geometry.m, geometry.n, scratch, &f)?;
             }
         } else {
@@ -336,7 +338,7 @@ impl TypedOp for LirMatMulUnary {
                     )
                     .unwrap();
 
-                let c_fact = TypedFact::dt_shape(cast, self.c_fact.shape.clone());
+                let c_fact = cast.fact(self.c_fact.shape.clone());
                 let mut patch = TypedModelPatch::fuse_with_next(
                     model,
                     &node,
@@ -352,7 +354,7 @@ impl TypedOp for LirMatMulUnary {
                 return self.fuse_op_with_broadcast(
                     model,
                     node,
-                    &[ProtoFusedSpec::QScale(op.shift, op.policy, op.mult)],
+                    &[ProtoFusedSpec::Scaler(op.scaler)],
                     &[],
                 );
             }
