@@ -137,7 +137,7 @@ impl TypedOp for QMatMulUnary {
             };
         }
 
-        Ok(tvec!(TypedFact::dt_shape(self.output_type, c_shape)))
+        Ok(tvec!(self.output_type.fact(c_shape)))
     }
 
     fn invariants(&self, inputs: &[&TypedFact], outputs: &[&TypedFact]) -> TractResult<Invariants> {
@@ -628,6 +628,24 @@ mod test {
         .check();
     }
 
+    #[test]
+    fn scale_big() {
+        QMatMulUnaryProblemI8I8I8 {
+            a: arr2(&[[0],[0]]),
+            b: arr2(&[[0, 0]]),
+            bias: tensor0(0i32),
+            a0: -1,
+            b0: 1,
+            c0: 0,
+            a_scale: 1.0,
+            b_scale: 0.2,
+            c_scale: 0.05,
+            opt: true,
+            dyn_qp: false,
+        }
+        .check();
+    }
+
     fn round_ties_to_right(x: f32) -> i32 {
         (x + 0.5).floor() as i32
     }
@@ -682,13 +700,7 @@ mod test {
                 let mut inputs = tvec![];
                 inputs.push(
                     model
-                    .add_source(
-                        "b",
-                        TypedFact::dt_shape(
-                            <$b>::datum_type(),
-                            &[self.b.nrows(), self.b.ncols()],
-                            ),
-                            )
+                    .add_source("b", <$b>::datum_type().fact(&[self.b.nrows(), self.b.ncols()]))
                     .unwrap(),
                     );
                 let qparams = if self.dyn_qp {
