@@ -1,8 +1,10 @@
 mod data_formats;
 mod reduce;
+mod softmax;
 
 pub use self::data_formats::{BaseDataShape, DataFormat, DataShape, SymDataShape};
 pub use self::reduce::{Reduce, Reducer};
+pub use self::softmax::Softmax;
 
 pub use crate::internal::*;
 
