@@ -4,6 +4,7 @@ use crate::ops::math::QScale;
 use num_traits::AsPrimitive;
 use tract_linalg::lut::Lut;
 use tract_linalg::mmm::RoundingPolicy;
+use tract_linalg::Scaler;
 
 use super::math::round_ties_to_even;
 
@@ -186,8 +187,7 @@ impl TypedOp for DequantizeLinearF32 {
                 // or else make a lookup table
                 if incoming_dt == DatumType::I8 || incoming_dt == DatumType::U8 {
                     let mut adhoc_model = TypedModel::default();
-                    let mut wire =
-                        adhoc_model.add_source("ad-hoc", TypedFact::dt_shape(dt, &[256]))?;
+                    let mut wire = adhoc_model.add_source("ad-hoc", dt.fact(&[256]))?;
                     let mut next = model.single_succ(dequant.id)?.unwrap();
                     let mut name = None;
                     // plug in dequant
@@ -350,19 +350,9 @@ impl crate::ops::binary::BinMiniOp for Scale {
             return Ok(Some(TypedModelPatch::shunt_one_op(model, node)?));
         } else if a.is_uniform() && node.outputs[0].fact.datum_type == DatumType::I32 {
             let factor = *a.to_scalar::<f32>()?;
-            if factor <= 0.0 || factor >= 0.5 {
-                return Ok(None);
-            }
-            let factor_bits = factor.to_bits();
-            let current_exponent = factor_bits >> 23;
-            let bumped_multi = f32::from_bits(factor_bits & 0x007fffff | 0x3f000000);
-            let int_multi = (bumped_multi * (1i64 << 31) as f32).round() as i32;
-            let shift = 126usize - current_exponent as usize;
-            let op = ElementWiseOp(Box::new(QScale {
-                mult: int_multi,
-                shift,
-                policy: RoundingPolicy::Even,
-            }));
+            let scaler = Scaler::new(factor, RoundingPolicy::Even);
+
+            let op = ElementWiseOp(Box::new(QScale { scaler }));
             let patch = TypedModelPatch::replace_single_op(model, node, &*node.inputs, op)?;
 
             return Ok(Some(patch));
@@ -407,7 +397,7 @@ pub mod scale {
             let input = tvec!(tensor2(&[[b]]));
             let mut model = TypedModel::default();
             let a = model.add_const("a", tensor2(&[[a]])).unwrap();
-            let b = model.add_source("b", TypedFact::dt_shape(i8::datum_type(), &[1, 1])).unwrap();
+            let b = model.add_source("b", i8::fact(&[1, 1])).unwrap();
             let bias = model.add_const("bias", tensor0(0i32)).unwrap();
             let mut qp = ops::matmul::MatMulQParams::noop_static(i8::datum_type());
             qp.c_scale = tensor0(scale).into();
