@@ -273,25 +273,24 @@ impl TypedOp for LirScan {
             let (outside_slot, axis, chunk) = self
                 .input_mapping
                 .iter()
-                .filter_map(|it| match it {
+                .find_map(|it| match it {
                     InputMapping::Scan { axis, slot, chunk } => Some((*slot, *axis, *chunk)),
                     _ => None,
                 })
-                .next()
                 .unwrap();
             inputs[outside_slot].shape[axis].clone().div_ceil(chunk.abs() as _)
         };
         for (ix, output) in self.output_mapping.iter().enumerate() {
             let fact = self.plan.model().output_fact(ix)?;
             if let Some(slot) = output.last_value_slot {
-                outputs.push((slot, TypedFact::dt_shape(fact.datum_type, fact.shape.clone())));
+                outputs.push((slot, fact.datum_type.fact(fact.shape.clone())));
             }
             if let Some(slot) = output.full_slot {
                 let mut shape = fact.shape.clone();
                 let scanning_dim =
                     output.full_dim_hint.clone().unwrap_or(shape[output.axis].clone() * &iters);
                 shape.set(output.axis, scanning_dim);
-                outputs.push((slot, TypedFact::dt_shape(fact.datum_type, shape)));
+                outputs.push((slot, fact.datum_type.fact(shape)));
             }
         }
         outputs.sort_by_key(|a| a.0);
